==> senior_design_system-0.21.4.tar.gz: example/lib/pages/rating.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class RatingExample extends StatefulWidget {
  const RatingExample({Key? key}) : super(key: key);

  @override
  _RatingExampleState createState() => _RatingExampleState();
}

class _RatingExampleState extends State<RatingExample> {
  bool isDisabled = false;
  double ratingOne = 3.0;
  double ratingTwo = 3.5;
  double ratingThree = 2.0;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Rating',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    isDisabled = !value;
                  });
                },
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Apenas avaliações inteiras',
                      child: Center(
                        child: SeniorRating(
                          itemCount: 5,
                          allowHalfRating: false,
                          direction: Axis.horizontal,
                          initialRating: ratingOne,
                          disabled: isDisabled,
                          onRatingUpdate: (double rating) {
                            setState(() {
                              ratingOne = rating;
                            });
                          },
                        ),
                      ),
                    ),
                    Panel(
                      title: 'Meia-avaliação',
                      child: Center(
                        child: SeniorRating(
                          itemCount: 5,
                          allowHalfRating: true,
                          direction: Axis.horizontal,
                          initialRating: ratingTwo,
                          itemSize: 32.0,
                          itemPadding: const EdgeInsets.symmetric(horizontal: 16.0),
                          disabled: isDisabled,
                          onRatingUpdate: (double rating) {
                            setState(() {
                              ratingTwo = rating;
                            });
                          },
                        ),
                      ),
                    ),
                    Panel(
                      title: 'Sem interação',
                      child: Center(
                        child: SeniorRating(
                          itemCount: 5,
                          initialRating: ratingThree,
                          ignoreGestures: true,
                          disabled: isDisabled,
                          onRatingUpdate: (_) {},
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Column(
                children: [
                  Text(
                    'Primeira avaliação: $ratingOne',
                    style: SeniorTypography.text(
                      color: SeniorColors.secondaryColor600,
                    ),
                  ),
                  Text(
                    'Segunda avaliação: $ratingTwo',
                    style: SeniorTypography.text(
                      color: SeniorColors.secondaryColor600,
                    ),
                  ),
                  Text(
                    'Terceira avaliação: $ratingThree',
                    style: SeniorTypography.text(
                      color: SeniorColors.secondaryColor600,
                    ),
                  ),
                ],
              )
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-0.26.2.tar.gz: example/lib/pages/rating.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class RatingExample extends StatefulWidget {
  const RatingExample({Key? key}) : super(key: key);

  @override
  _RatingExampleState createState() => _RatingExampleState();
}

class _RatingExampleState extends State<RatingExample> {
  bool isDisabled = false;
  double ratingOne = 3.0;
  double ratingTwo = 3.5;
  double ratingThree = 2.0;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Rating',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !isDisabled,
                onChanged: (value) {
                  if (value == null) {
                    return;
                  }
                  setState(() {
                    isDisabled = !value;
                  });
                },
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Apenas avaliações inteiras',
                      child: Center(
                        child: SeniorRating(
                          itemCount: 5,
                          allowHalfRating: false,
                          direction: Axis.horizontal,
                          initialRating: ratingOne,
                          disabled: isDisabled,
                          onRatingUpdate: (double rating) {
                            setState(() {
                              ratingOne = rating;
                            });
                          },
                        ),
                      ),
                    ),
                    Panel(
                      title: 'Meia-avaliação',
                      child: Center(
                        child: SeniorRating(
                          itemCount: 5,
                          allowHalfRating: true,
                          direction: Axis.horizontal,
                          initialRating: ratingTwo,
                          itemSize: 32.0,
                          itemPadding:
                              const EdgeInsets.symmetric(horizontal: 16.0),
                          disabled: isDisabled,
                          onRatingUpdate: (double rating) {
                            setState(() {
                              ratingTwo = rating;
                            });
                          },
                        ),
                      ),
                    ),
                    Panel(
                      title: 'Sem interação',
                      child: Center(
                        child: SeniorRating(
                          itemCount: 5,
                          initialRating: ratingThree,
                          ignoreGestures: true,
                          disabled: isDisabled,
                          onRatingUpdate: (_) {},
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Column(
                children: [
                  Text(
                    'Primeira avaliação: $ratingOne',
                    style: SeniorTypography.text(
                      color: SeniorColors.secondaryColor600,
                    ),
                  ),
                  Text(
                    'Segunda avaliação: $ratingTwo',
                    style: SeniorTypography.text(
                      color: SeniorColors.secondaryColor600,
                    ),
                  ),
                  Text(
                    'Terceira avaliação: $ratingThree',
                    style: SeniorTypography.text(
                      color: SeniorColors.secondaryColor600,
                    ),
                  ),
                ],
              )
            ],
          ),
        ),
      ),
    );
  }
}
